@@ -23,22 +23,31 @@
 #' First element may also be model object. If a model objects is provided, its
 #' formula is used as first formula, and all independent variables will be used
 #' for the `adjusted` argument. See 'Details' and 'Examples'.
-#' @param outcome Name of the dependent variable (outcome), as character string.
-#' Must be a valid name from the formulas. If not set, the first dependent
-#' variable from the formulas is used.
-#' @param exposure Name of the exposure variable (as character string), for
-#' which the direct and total causal effect on the `outcome` should be checked.
-#' Must be a valid name from the formulas. If not set, the first independent
-#' variable from the formulas is used.
-#' @param adjusted A character vector with names of variables that are adjusted
-#' for in the model. If a model object is provided in `...`, any values in
+#' @param outcome Name of the dependent variable (outcome), as character string
+#' or as formula. Must be a valid name from the formulas provided in `...`. If
+#' not set, the first dependent variable from the formulas is used.
+#' @param exposure Name of the exposure variable (as character string or
+#' formula), for which the direct and total causal effect on the `outcome`
+#' should be checked. Must be a valid name from the formulas provided in `...`.
+#' If not set, the first independent variable from the formulas is used.
+#' @param adjusted A character vector or formula with names of variables that
+#' are adjusted for in the model, e.g. `adjusted = c("x1", "x2")` or
+#' `adjusted = ~ x1 + x2`. If a model object is provided in `...`, any values in
 #' `adjusted` will be overwritten by the model's independent variables.
 #' @param latent A character vector with names of latent variables in the model.
 #' @param effect Character string, indicating which effect to check. Can be
 #' `"all"` (default), `"total"`, or `"direct"`.
-#' @param coords A list with two elements, `x` and `y`, which both are named
-#' vectors of numerics. The names correspond to the variable names in the DAG,
-#' and the values for `x` and `y` indicate the x/y coordinates in the plot.
+#' @param coords Coordinates of the variables when plotting the DAG. The
+#' coordinates can be provided in three different ways:
+#'
+#' - a list with two elements, `x` and `y`, which both are named vectors of
+#'   numerics. The names correspond to the variable names in the DAG, and the
+#'   values for `x` and `y` indicate the x/y coordinates in the plot.
+#' - a list with elements that correspond to the variables in the DAG. Each
+#'   element is a numeric vector of length two with x- and y-coordinate.
+#' - a data frame with three columns: `x`, `y` and `name` (which contains the
+#'   variable names).
+#'
 #' See 'Examples'.
 #' @param x An object of class `check_dag`, as returned by `check_dag()`.
 #'
@@ -68,6 +77,13 @@
 #' adjusted for both. If the model is cyclic, the function stops and suggests
 #' to remove cycles from the model.
 #'
+#' Note that it sometimes could be necessary to try out different combinations
+#' of suggested adjustments, because `check_dag()` can not always detect whether
+#' _at least_ one of several variables is required, or whether adjustments should
+#' be done for _all_ listed variables. It can be useful to copy the dagitty-code
+#' (using `as.dag()`, which prints the dagitty-string into the console) into
+#' the dagitty-website and play around with different adjustments.
+#'
 #' @section Direct and total effects:
 #'
 #' The direct effect of an exposure on an outcome is the effect that is not
@@ -103,7 +119,7 @@
 #'   Interpreting Confounder and Modifier Coefficients. American Journal of
 #'   Epidemiology, 177(4), 292–298. \doi{10.1093/aje/kws412}
 #'
-#' @examplesIf require("ggdag", quietly = TRUE) && require("dagitty", quietly = TRUE) && require("see", quietly = TRUE) && packageVersion("see") > "0.8.5"
+#' @examplesIf require("ggdag", quietly = TRUE) && require("dagitty", quietly = TRUE) && require("see", quietly = TRUE)
 #' # no adjustment needed
 #' check_dag(
 #'   y ~ x + b,
@@ -131,6 +147,23 @@
 #' )
 #' dag
 #'
+#' # using formula interface for arguments "outcome", "exposure" and "adjusted"
+#' check_dag(
+#'   y ~ x + b + c,
+#'   x ~ b,
+#'   outcome = ~y,
+#'   exposure = ~x,
+#'   adjusted = ~ b + c
+#' )
+#'
+#' # if not provided, "outcome" is taken from first formula, same for "exposure"
+#' # thus, we can simplify the above expression to
+#' check_dag(
+#'   y ~ x + b + c,
+#'   x ~ b,
+#'   adjusted = ~ b + c
+#' )
+#'
 #' # use specific layout for the DAG
 #' dag <- check_dag(
 #'   score ~ exp + b + c,
@@ -146,6 +179,22 @@
 #' )
 #' plot(dag)
 #'
+#' # alternative way of providing the coordinates
+#' dag <- check_dag(
+#'   score ~ exp + b + c,
+#'   exp ~ b,
+#'   outcome = "score",
+#'   exposure = "exp",
+#'   coords = list(
+#'     # x/y coordinates for each node
+#'     score = c(5, 3),
+#'     exp = c(4, 3),
+#'     b = c(3, 2),
+#'     c = c(3, 4)
+#'   )
+#' )
+#' plot(dag)
+#'
 #' # Objects returned by `check_dag()` can be used with "ggdag" or "dagitty"
 #' ggdag::ggdag_status(dag)
 #'
@@ -211,6 +260,21 @@ check_dag <- function(...,
     )$conditional[1]
   }
 
+  # handle formula interface - if "outcome", "exposure" or "adjusted" are
+  # provided as formulas, convert to character here
+  if (inherits(outcome, "formula")) {
+    outcome <- all.vars(outcome)
+  }
+  if (inherits(exposure, "formula")) {
+    exposure <- all.vars(exposure)
+  }
+  if (inherits(adjusted, "formula")) {
+    adjusted <- all.vars(adjusted)
+  }
+
+  # process coords-argument
+  coords <- .process_coords(coords)
+
   # convert to dag
   dag_args <- c(formulas, list(
     exposure = exposure,
@@ -247,11 +311,27 @@ check_dag <- function(...,
   checks <- lapply(c("direct", "total"), function(x) {
     adjustment_set <- unlist(dagitty::adjustmentSets(dag, effect = x), use.names = FALSE)
     adjustment_nodes <- unlist(dagitty::adjustedNodes(dag), use.names = FALSE)
+    minimal_adjustments <- as.list(dagitty::adjustmentSets(dag, effect = x))
+    collider <- adjustment_nodes[vapply(adjustment_nodes, ggdag::is_collider, logical(1), .dag = dag, downstream = FALSE)] # nolint
+    if (length(collider)) {
+      # if we *have* colliders, remove them from minimal adjustments
+      minimal_adjustments <- lapply(minimal_adjustments, setdiff, y = collider)
+    } else {
+      # if we don't have colliders, set to NULL
+      collider <- NULL
+    }
     list(
-      adjustment_not_needed = is.null(adjustment_set) && is.null(adjustment_nodes),
-      incorrectly_adjusted = is.null(adjustment_set) && !is.null(adjustment_nodes),
+      # no adjustment needed when
+      # - required and current adjustment sets are NULL
+      # - AND we have no collider in current adjustments
+      adjustment_not_needed = is.null(adjustment_set) && is.null(adjustment_nodes) && is.null(collider),
+      # incorrect adjustment when
+      # - required is NULL and current adjustment not NULL
+      # - OR we have a collider in current adjustments
+      incorrectly_adjusted = (is.null(adjustment_set) && !is.null(adjustment_nodes)) || (!is.null(collider) && collider %in% adjustment_nodes), # nolint
       current_adjustments = adjustment_nodes,
-      minimal_adjustments = as.list(dagitty::adjustmentSets(dag, effect = x))
+      minimal_adjustments = minimal_adjustments,
+      collider = collider
     )
   })
 
@@ -260,6 +340,10 @@ check_dag <- function(...,
   attr(dag, "exposure") <- exposure
   attr(dag, "adjusted") <- adjusted
   attr(dag, "adjustment_sets") <- checks[[1]]$current_adjustments
+  attr(dag, "collider") <- checks[[1]]$collider
+  # remove collider from sub-attributes
+  checks[[1]]$collider <- NULL
+  checks[[2]]$collider <- NULL
   attr(dag, "check_direct") <- insight::compact_list(checks[[1]])
   attr(dag, "check_total") <- insight::compact_list(checks[[2]])
 
@@ -281,6 +365,39 @@ check_dag <- function(...,
 }
 
 
+.process_coords <- function(coords) {
+  # check if the coords are not provided as list with x/y elements, but instead
+  # as list x/y coordinates for each element. This means, "coords" is provided as
+  #
+  # coords <- list(
+  #   score = c(5, 3),
+  #   exp = c(4, 3),
+  #   b = c(3, 2),
+  #   c = c(3, 4)
+  # )
+  #
+  # but we want
+  #
+  # coords = list(
+  #   x = c(score = 5, exp = 4, b = 3, c = 3),
+  #   y = c(score = 3, exp = 3, b = 2, c = 4)
+  # )
+  #
+  # we have to check that it's not a data frame and that it is a list -
+  # values like `ggdag::time_ordered_coords()` returns a function, not a list
+  if (!is.null(coords) && !is.data.frame(coords) && is.list(coords) && (length(coords) != 2 || !identical(names(coords), c("x", "y")))) { # nolint
+    # transform list into data frame, split x and y coordinates into columns
+    coords <- datawizard::rownames_as_column(
+      stats::setNames(as.data.frame(do.call(rbind, coords)), c("x", "y")),
+      "name"
+    )
+    # reorder
+    coords <- coords[c("x", "y", "name")]
+  }
+  coords
+}
+
+
 # methods --------------------------------------------------------------------
 
 #' @rdname check_dag
@@ -296,6 +413,7 @@ as.dag <- function(x, ...) {
 #' @export
 print.check_dag <- function(x, ...) {
   effect <- attributes(x)$effect
+  collider <- attributes(x)$collider
 
   # header
   cat(insight::print_color("# Check for correct adjustment sets", "blue"))
@@ -317,13 +435,23 @@ print.check_dag <- function(x, ...) {
     )
   }
 
+  # add information on colliders
+  if (!is.null(collider)) {
+    exposure_outcome_text <- paste0(
+      exposure_outcome_text,
+      "\n- Collider",
+      ifelse(length(collider) > 1, "s", ""),
+      ": ", insight::color_text(datawizard::text_concatenate(collider), "cyan")
+    )
+  }
+
   cat(exposure_outcome_text)
   cat("\n\n")
 
   # minimal adjustment sets for direct and total effect identical?
   # Then print only once
   if (identical(attributes(x)$check_direct$minimal_adjustments, attributes(x)$check_total$minimal_adjustments)) {
-    .print_dag_results(attributes(x)$check_direct, x, "direct and total", "all")
+    .print_dag_results(attributes(x)$check_direct, x, "direct and total", "all", collider)
   } else {
     for (i in c("direct", "total")) {
       if (i == "direct") {
@@ -331,12 +459,12 @@ print.check_dag <- function(x, ...) {
       } else {
         out <- attributes(x)$check_total
       }
-      .print_dag_results(out, x, i, effect)
+      .print_dag_results(out, x, i, effect, collider)
     }
   }
 }
 
-.print_dag_results <- function(out, x, i, effect) {
+.print_dag_results <- function(out, x, i, effect, collider = NULL) {
   # missing adjustements - minimal_adjustment can be a list of different
   # options for minimal adjustements, so we check here if any of the minimal
   # adjustments are currently sufficient
@@ -356,24 +484,35 @@ print.check_dag <- function(x, ...) {
       attributes(x)$outcome,
       "`."
     )
+  } else if (!is.null(collider)) {
+    # Scenario 2: adjusted for collider
+    msg <- paste0(
+      insight::color_text("Incorrectly adjusted!", "red"),
+      "\nYour model adjusts for a potential collider. To estimate the ", i, " effect, do ",
+      insight::color_text("not", "italic"),
+      " adjust for ",
+      insight::color_text(datawizard::text_concatenate(collider, enclose = "`"), "cyan"),
+      " to avoid collider-bias. It is recommended to double-check for the collider-bias on the dagitty-website."
+    )
   } else if (isTRUE(out$incorrectly_adjusted)) {
-    # Scenario 2: incorrectly adjusted, adjustments where none is allowed
+    # Scenario 3: incorrectly adjusted, adjustments where none is allowed
     msg <- paste0(
       insight::color_text("Incorrectly adjusted!", "red"),
       "\nTo estimate the ", i, " effect, do ",
       insight::color_text("not", "italic"),
       " adjust for ",
-      datawizard::text_concatenate(out$current_adjustments, enclose = "`"),
+      ifelse(length(out$current_adjustments) > 1, "some or all of ", ""),
+      insight::color_text(datawizard::text_concatenate(out$current_adjustments, enclose = "`"), "red"),
       "."
     )
   } else if (any(sufficient_adjustments)) {
-    # Scenario 3: correct adjustment
+    # Scenario 4: correct adjustment
     msg <- paste0(
       insight::color_text("Model is correctly specified.", "green"),
       "\nAll minimal sufficient adjustments to estimate the ", i, " effect were done."
     )
   } else {
-    # Scenario 4: missing adjustments
+    # Scenario 5: missing adjustments
     msg <- paste0(
       insight::color_text("Incorrectly adjusted!", "red"),
       "\nTo estimate the ", i, " effect, ",
@@ -395,6 +534,7 @@ print.check_dag <- function(x, ...) {
         ),
         "."
       )
+      current_str <- "\nCurrently"
     } else {
       msg <- paste0(
         msg,
@@ -404,14 +544,25 @@ print.check_dag <- function(x, ...) {
         ), "yellow"),
         "."
       )
+      current_str <- " Currently"
     }
     if (is.null(out$current_adjustments)) {
-      msg <- paste0(msg, "\nCurrently, the model does not adjust for any variables.")
+      msg <- paste0(msg, current_str, ", the model does not adjust for any variables.")
     } else {
       msg <- paste0(
-        msg, "\nCurrently, the model only adjusts for ",
-        insight::color_text(datawizard::text_concatenate(out$current_adjustments, enclose = "`"), "yellow"), "."
+        msg, current_str, ", the model only adjusts for ",
+        datawizard::text_concatenate(out$current_adjustments, enclose = "`"),
+        "."
       )
+      # check if we could identify missing variables, and if so, add them to the message
+      missing_vars <- setdiff(unlist(out$minimal_adjustments), out$current_adjustments)
+      if (length(missing_vars) > 0) {
+        msg <- paste0(
+          msg, " You possibly also need to adjust for ",
+          insight::color_text(datawizard::text_concatenate(missing_vars, enclose = "`"), "green"),
+          " to block biasing paths."
+        )
+      }
     }
   }
 
