@@ -70,14 +70,14 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "leve
     )
 
     if (is.null(check)) {
-      insight::print_color("'check_homogeneity()' cannot perform check for normality. Please specify the 'method'-argument for the test of equal variances.\n", "red")
+      insight::print_color("'check_homogeneity()' cannot perform check for normality. Please specify the 'method'-argument for the test of equal variances.\n", "red") # nolint
       return(NULL)
     }
 
     method <- ifelse(check < 0.05, "fligner", "bartlett")
   }
 
-  if (method == "fligner") {
+  if (method == "fligner") { # nolint
     r <- stats::fligner.test(f, data = insight::get_data(x, verbose = FALSE))
     p.val <- r$p.value
   } else if (method == "bartlett") {
@@ -117,7 +117,7 @@ print.check_homogeneity <- function(x, ...) {
   } else if (x < 0.05) {
     insight::print_color(sprintf("Warning: Variances differ between groups (%s, p = %.3f).\n", method.string, x), "red")
   } else {
-    insight::print_color(sprintf("OK: There is not clear evidence for different variances across groups (%s, p = %.3f).\n", method.string, x), "green")
+    insight::print_color(sprintf("OK: There is not clear evidence for different variances across groups (%s, p = %.3f).\n", method.string, x), "green") # nolint
   }
   invisible(x)
 }
@@ -146,18 +146,18 @@ check_homogeneity.afex_aov <- function(x, method = "levene", ...) {
     insight::format_error("Levene test is only aplicable to ANOVAs with between-subjects factors.")
   }
 
-  data <- x$data$long # Use this to also get id column
+  long_data <- x$data$long # Use this to also get id column
   dv <- attr(x, "dv")
   id <- attr(x, "id")
   between <- names(attr(x, "between"))
   is_covar <- vapply(attr(x, "between"), is.null, logical(1))
 
-  ag_data <- stats::aggregate(data[, dv], data[, c(between, id)], mean)
+  ag_data <- stats::aggregate(long_data[, dv], long_data[, c(between, id)], mean)
   colnames(ag_data)[length(c(between, id)) + 1] <- dv
 
   if (any(is_covar)) {
     insight::format_alert(
-      "Levene's test is not appropriate with quantitative explanatory variables. Testing assumption of homogeneity among factor groups only."
+      "Levene's test is not appropriate with quantitative explanatory variables. Testing assumption of homogeneity among factor groups only." # nolint
     )
     # ## TODO maybe add as option?
     # warning("Testing assumption of homogeneity on residualzied data among factor groups only.", call. = FALSE)
@@ -165,7 +165,7 @@ check_homogeneity.afex_aov <- function(x, method = "levene", ...) {
     between <- between[!is_covar]
   }
 
-  form <- stats::formula(paste0(dv, "~", paste0(between, collapse = "*")))
+  form <- stats::formula(paste0(dv, "~", paste(between, collapse = "*")))
   test <- car::leveneTest(form, ag_data, center = mean, ...)
 
   p.val <- test[1, "Pr(>F)"]
