@@ -10,6 +10,9 @@
 #' (`TRUE`) or not (`FALSE`)?
 #' @param ci Confidence interval level, as scalar. If `NULL` (default), no
 #' confidence intervals for R2 are calculated.
+#' @param multivariate Logical. Should multiple R2 values be reported as
+#' separated by response (FALSE) or should a single R2 be reported as
+#' combined across responses computed by [`r2_mlm`] (TRUE).
 #' @param ... Arguments passed down to the related r2-methods.
 #' @inheritParams r2_nakagawa
 #'
@@ -23,14 +26,15 @@
 #'   - Mixed models: [Nakagawa's R2][r2_nakagawa]
 #'   - Bayesian models: [R2 bayes][r2_bayes]
 #'
-#' @note If there is no `r2()`-method defined for the given model class,
-#'   `r2()` tries to return a "generic" r-quared value, calculated as following:
-#'   `1-sum((y-y_hat)^2)/sum((y-y_bar)^2))`
+#' @note
+#' If there is no `r2()`-method defined for the given model class, `r2()` tries
+#' to return a "generic" r-quared value, calculated as following:
+#' `1-sum((y-y_hat)^2)/sum((y-y_bar)^2)`
 #'
-#' @seealso [`r2_bayes()`], [`r2_coxsnell()`], [`r2_kullback()`],
-#'   [`r2_loo()`], [`r2_mcfadden()`], [`r2_nagelkerke()`],
-#'   [`r2_nakagawa()`], [`r2_tjur()`], [`r2_xu()`] and
-#'   [`r2_zeroinflated()`].
+#' @seealso
+#' [`r2_bayes()`], [`r2_coxsnell()`], [`r2_kullback()`], [`r2_loo()`],
+#' [`r2_mcfadden()`], [`r2_nagelkerke()`], [`r2_nakagawa()`], [`r2_tjur()`],
+#' [`r2_xu()`], [`r2_zeroinflated()`], and [`r2_mlm()`].
 #'
 #' @examplesIf require("lme4")
 #' # Pseudo r-quared for GLM
@@ -244,24 +248,28 @@ r2.aov <- function(model, ci = NULL, ...) {
   structure(class = "r2_generic", out)
 }
 
-
+#' @rdname r2
 #' @export
-r2.mlm <- function(model, ...) {
-  model_summary <- summary(model)
+r2.mlm <- function(model, multivariate = TRUE, ...) {
+  if (multivariate) {
+    out <- r2_mlm(model)
+  } else {
+    model_summary <- summary(model)
 
-  out <- lapply(names(model_summary), function(i) {
-    tmp <- list(
-      R2 = model_summary[[i]]$r.squared,
-      R2_adjusted = model_summary[[i]]$adj.r.squared,
-      Response = sub("Response ", "", i, fixed = TRUE)
-    )
-    names(tmp$R2) <- "R2"
-    names(tmp$R2_adjusted) <- "adjusted R2"
-    names(tmp$Response) <- "Response"
-    tmp
-  })
+    out <- lapply(names(model_summary), function(i) {
+      tmp <- list(
+        R2 = model_summary[[i]]$r.squared,
+        R2_adjusted = model_summary[[i]]$adj.r.squared,
+        Response = sub("Response ", "", i, fixed = TRUE)
+      )
+      names(tmp$R2) <- "R2"
+      names(tmp$R2_adjusted) <- "adjusted R2"
+      names(tmp$Response) <- "Response"
+      tmp
+    })
 
-  names(out) <- names(model_summary)
+    names(out) <- names(model_summary)
+  }
 
   attr(out, "model_type") <- "Multivariate Linear"
   structure(class = "r2_mlm", out)
@@ -291,6 +299,12 @@ r2.glm <- function(model, ci = NULL, verbose = TRUE, ...) {
       insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
     }
     out <- NULL
+  } else if (info$is_orderedbeta) {
+    # ordered-beta-regression
+    out <- r2_ferrari(model, correct_bounds = TRUE)
+  } else if (info$is_beta) {
+    # beta-regression
+    out <- r2_ferrari(model)
   } else {
     out <- list(R2_Nagelkerke = r2_nagelkerke(model, ...))
     names(out$R2_Nagelkerke) <- "Nagelkerke's R2"
@@ -386,6 +400,9 @@ r2.censReg <- function(model, ...) {
 #' @export
 r2.cpglm <- r2.censReg
 
+#' @export
+r2.serp <- r2.censReg
+
 #' @export
 r2.clm <- r2.censReg
 
@@ -524,8 +541,20 @@ r2.glmmTMB <- function(model, ci = NULL, tolerance = 1e-5, verbose = TRUE, ...)
     } else if (info$is_zero_inflated) {
       # zero-inflated models use the default method
       out <- r2_zeroinflated(model)
+    } else if (info$is_orderedbeta) {
+      # ordered-beta-regression
+      out <- r2_ferrari(model, correct_bounds = TRUE)
+    } else if (info$is_beta) {
+      # beta-regression
+      out <- r2_ferrari(model)
     } else {
-      insight::format_error("`r2()` does not support models of class `glmmTMB` without random effects and this link-function.") # nolint
+      insight::format_error(paste0(
+        "`r2()` does not support models of class `glmmTMB` without random effects and from ",
+        info$family,
+        "-family with ",
+        info$link_function,
+        "-link-function."
+      ))
     }
   }
   out
